@@ -28,7 +28,7 @@
 #include <audiocdencoder.h>
 #include <sys/stat.h>
 #include <unistd.h>
-#include <stdlib.h>
+#include <cstdlib>
 
 /**
  * Raw cd "encoder"
